@@ -135,8 +135,10 @@ sub GetSessionIDData {
 create a new session with given data
 
     my $SessionID = $SessionObject->CreateSessionID(
-        UserLogin => 'root',
-        UserEmail => 'root@example.com',
+        UserType      => 'User',                # required, 'User' or 'Customer'
+        UserLogin     => 'root',
+        UserEmail     => 'root@example.com',
+        SessionSource => 'GenericInterface',    # optional, used to identify the source of the session
     );
 
 =cut
@@ -162,9 +164,25 @@ sub CreateSessionID {
         return;
     }
 
-    $CacheObject->CleanUp(
-        Type => 'User',
-    );
+    # Clear cached data of this user (agent).
+    if (
+        $Param{UserType} eq 'User'
+        && $Param{UserLogin}
+        )
+    {
+        my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
+        my $UserID = $UserObject->UserLookup(
+            UserLogin => $Param{UserLogin},
+            Silent    => 1,
+        );
+
+        if ($UserID) {
+
+            # Note: This function should be public, not private.
+            $UserObject->_UserCacheClear( UserID => $UserID );
+        }
+    }
 
     my $SessionLimit;
     if ( $Param{UserType} eq 'User' ) {
@@ -226,9 +244,20 @@ sub RemoveSessionID {
 
     my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
 
-    $CacheObject->CleanUp(
-        Type => 'User',
+    # Clear cached data of the session's user (agent).
+    my %SessionData = $Self->GetSessionIDData(
+        SessionID => $Param{SessionID},
     );
+    if (
+        ( $SessionData{UserType} // '' ) eq 'User'
+        && $SessionData{UserID}
+        )
+    {
+        my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
+        # Note: This function should be public, not private.
+        $UserObject->_UserCacheClear( UserID => $SessionData{UserID} );
+    }
 
     return $Self->{Backend}->RemoveSessionID(%Param);
 }
@@ -265,7 +294,13 @@ sub RemoveSessionByUser {
             SessionID => $SessionID,
         );
 
-        next SESSIONID if $SessionData{UserLogin} ne $Param{UserLogin};
+        if (
+            defined $SessionData{UserLogin}
+            && ( $SessionData{UserLogin} ne $Param{UserLogin} )
+            )
+        {
+            next SESSIONID;
+        }
 
         $Self->{Backend}->RemoveSessionID(
             SessionID => $SessionID,
@@ -376,6 +411,34 @@ sub GetActiveSessions {
     return $Self->{Backend}->GetActiveSessions(%Param);
 }
 
+=head2 GetOrphanedSessionIDs()
+
+returns an array with orphaned session ids,
+missing user-login defines an orphaned session for now
+
+    my @Sessions = $SessionObject->GetOrphanedSessionIDs();
+
+=cut
+
+sub GetOrphanedSessionIDs {
+    my ( $Self, %Param ) = @_;
+
+    my @OrphanedSessionIDs;
+    my @SessionIDs = $Self->GetAllSessionIDs();
+    for my $SessionID (@SessionIDs) {
+
+        my %SessionData = $Self->{Backend}->GetSessionIDData(
+            SessionID => $SessionID,
+        );
+
+        if ( !defined $SessionData{UserLogin} ) {
+            push @OrphanedSessionIDs, $SessionID;
+        }
+    }
+
+    return @OrphanedSessionIDs;
+}
+
 =head2 CleanUp()
 
 clean-up of sessions in your system
