@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -64,17 +64,18 @@ sub new {
 
 return a hash of all possible types
 
-Return
-    %PossibleTypesList = (
-        'Normal'      => 1,
-        'ParentChild' => 1,
-    );
-
     my %PossibleTypesList = $LinkObject->PossibleTypesList(
         Object1 => 'Ticket',
         Object2 => 'FAQ',
     );
 
+Return:
+
+    %PossibleTypesList = (
+        'Normal'      => 1,
+        'ParentChild' => 1,
+    );
+
 =cut
 
 sub PossibleTypesList {
@@ -143,16 +144,17 @@ sub PossibleTypesList {
 
 return a hash of all possible objects
 
-Return
+    my %PossibleObjectsList = $LinkObject->PossibleObjectsList(
+        Object => 'Ticket',
+    );
+
+Return:
+
     %PossibleObjectsList = (
         'Ticket' => 1,
         'FAQ'    => 1,
     );
 
-    my %PossibleObjectsList = $LinkObject->PossibleObjectsList(
-        Object => 'Ticket',
-    );
-
 =cut
 
 sub PossibleObjectsList {
@@ -199,7 +201,10 @@ sub PossibleObjectsList {
 
 return a 2 dimensional hash list of all possible links
 
-Return
+    my %PossibleLinkList = $LinkObject->PossibleLinkList();
+
+Return:
+
     %PossibleLinkList = (
         001 => {
             Object1 => 'Ticket',
@@ -213,7 +218,6 @@ Return
         },
     );
 
-    my %PossibleLinkList = $LinkObject->PossibleLinkList();
 
 =cut
 
@@ -252,7 +256,7 @@ sub PossibleLinkList {
             # log the error
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message =>
+                Message  =>
                     "The $Argument '$Value' is invalid in SysConfig (LinkObject::PossibleLink)!",
             );
 
@@ -344,7 +348,7 @@ sub LinkAdd {
     # check if source and target are the same object
     if ( $Param{SourceObject} eq $Param{TargetObject} && $Param{SourceKey} eq $Param{TargetKey} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
+            Priority => 'notice',
             Message  => 'Impossible to link object with itself!',
         );
         return;
@@ -379,7 +383,7 @@ sub LinkAdd {
     if ( !$PossibleTypesList{ $Param{Type} } ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message =>
+            Message  =>
                 "Not possible to create a '$Param{Type}' link between $Param{SourceObject} and $Param{TargetObject}!",
         );
         return;
@@ -437,7 +441,7 @@ sub LinkAdd {
         if ( $Existing{StateID} ne $StateID ) {
 
             $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
+                Priority => 'notice',
                 Message  => "Link already exists between these two objects "
                     . "with a different state id '$Existing{StateID}'!",
             );
@@ -455,7 +459,7 @@ sub LinkAdd {
 
         # log error
         $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
+            Priority => 'notice',
             Message  => 'Link already exists between these two objects in opposite direction!',
         );
         return;
@@ -495,7 +499,7 @@ sub LinkAdd {
 
             # existing link type is in a type group with the new link
             $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
+                Priority => 'notice',
                 Message  => 'Another Link already exists within the same type group!',
             );
 
@@ -542,22 +546,28 @@ sub LinkAdd {
         Bind => [
             \$Param{SourceObjectID}, \$Param{SourceKey},
             \$Param{TargetObjectID}, \$Param{TargetKey},
-            \$TypeID, \$StateID, \$Param{UserID},
+            \$TypeID,                \$StateID, \$Param{UserID},
         ],
     );
 
     # delete affected caches (both directions)
     my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
     for my $Direction (qw(Source Target)) {
-        my $CacheKey =
-            'Cache::LinkListRaw'
-            . '::Direction' . $Direction
-            . '::ObjectID' . $Param{ $Direction . 'ObjectID' }
-            . '::StateID' . $StateID;
-        $CacheObject->Delete(
-            Type => $Self->{CacheType},
-            Key  => $CacheKey,
-        );
+        for my $ObjectID ( $Param{SourceObjectID}, $Param{TargetObjectID} ) {
+            for my $Key ( $Param{SourceKey}, $Param{TargetKey} ) {
+                my $CacheKey =
+                    'Cache::LinkListRaw'
+                    . '::Direction' . $Direction
+                    . '::ObjectID' . $ObjectID
+                    . '::StateID' . $StateID
+                    . '::Key' . $Key;
+
+                $CacheObject->Delete(
+                    Type => $Self->{CacheType},
+                    Key  => $CacheKey,
+                );
+            }
+        }
     }
 
     # run post event module of source object
@@ -604,8 +614,8 @@ deletes old links from database
 return true
 
     $True = $LinkObject->LinkCleanup(
-        State  => 'Temporary',
-        Age    => ( 60 * 60 * 24 ),
+        State => 'Temporary',
+        Age   => ( 60 * 60 * 24 ),
     );
 
 =cut
@@ -831,17 +841,21 @@ sub LinkDelete {
     my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
     my %StateList   = $Self->StateList();
     for my $Direction (qw(Source Target)) {
-        for my $DirectionNumber (qw(1 2)) {
+        for my $ObjectID ( $Param{Object1ID}, $Param{Object2ID} ) {
             for my $StateID ( sort keys %StateList ) {
-                my $CacheKey =
-                    'Cache::LinkListRaw'
-                    . '::Direction' . $Direction
-                    . '::ObjectID' . $Param{ 'Object' . $DirectionNumber . 'ID' }
-                    . '::StateID' . $StateID;
-                $CacheObject->Delete(
-                    Type => $Self->{CacheType},
-                    Key  => $CacheKey,
-                );
+                for my $Key ( $Param{Key1}, $Param{Key2} ) {
+                    my $CacheKey =
+                        'Cache::LinkListRaw'
+                        . '::Direction' . $Direction
+                        . '::ObjectID' . $ObjectID
+                        . '::StateID' . $StateID
+                        . '::Key' . $Key;
+
+                    $CacheObject->Delete(
+                        Type => $Self->{CacheType},
+                        Key  => $CacheKey,
+                    );
+                }
             }
         }
     }
@@ -965,7 +979,18 @@ sub LinkDeleteAll {
 
 get all existing links for a given object
 
-Return
+    my $LinkList = $LinkObject->LinkList(
+        Object    => 'Ticket',
+        Key       => '321',
+        Object2   => 'FAQ',         # (optional)
+        State     => 'Valid',
+        Type      => 'ParentChild', # (optional)
+        Direction => 'Target',      # (optional) default Both (Source|Target|Both)
+        UserID    => 1,
+    );
+
+Return:
+
     $LinkList = {
         Ticket => {
             Normal => {
@@ -996,16 +1021,6 @@ Return
         },
     };
 
-    my $LinkList = $LinkObject->LinkList(
-        Object    => 'Ticket',
-        Key       => '321',
-        Object2   => 'FAQ',         # (optional)
-        State     => 'Valid',
-        Type      => 'ParentChild', # (optional)
-        Direction => 'Target',      # (optional) default Both (Source|Target|Both)
-        UserID    => 1,
-    );
-
 =cut
 
 sub LinkList {
@@ -1148,7 +1163,23 @@ sub LinkList {
 
 get all existing links for a given object with data of the other objects
 
-Return
+    my $LinkList = $LinkObject->LinkListWithData(
+        Object           => 'Ticket',
+        Key              => '321',
+        Object2          => 'FAQ',         # (optional)
+        State            => 'Valid',
+        Type             => 'ParentChild', # (optional)
+        Direction        => 'Target',      # (optional) default Both (Source|Target|Both)
+        UserID           => 1,
+        ObjectParameters => {              # (optional) backend specific flags
+            Ticket => {
+                IgnoreLinkedTicketStateTypes => 0|1,
+            },
+        },
+    );
+
+Return:
+
     $LinkList = {
         Ticket => {
             Normal => {
@@ -1179,21 +1210,6 @@ Return
         },
     };
 
-    my $LinkList = $LinkObject->LinkListWithData(
-        Object                          => 'Ticket',
-        Key                             => '321',
-        Object2                         => 'FAQ',         # (optional)
-        State                           => 'Valid',
-        Type                            => 'ParentChild', # (optional)
-        Direction                       => 'Target',      # (optional) default Both (Source|Target|Both)
-        UserID                          => 1,
-        ObjectParameters                => {              # (optional) backend specific flags
-            Ticket => {
-                IgnoreLinkedTicketStateTypes => 0|1,
-            },
-        },
-    );
-
 =cut
 
 sub LinkListWithData {
@@ -1292,15 +1308,6 @@ sub LinkListWithData {
 
 return a hash with all existing links of a given object
 
-Return
-    %LinkKeyList = (
-        5   => 1,
-        9   => 1,
-        12  => 1,
-        212 => 1,
-        332 => 1,
-    );
-
     my %LinkKeyList = $LinkObject->LinkKeyList(
         Object1   => 'Ticket',
         Key1      => '321',
@@ -1311,6 +1318,16 @@ Return
         UserID    => 1,
     );
 
+Return
+
+    %LinkKeyList = (
+        5   => 1,
+        9   => 1,
+        12  => 1,
+        212 => 1,
+        332 => 1,
+    );
+
 =cut
 
 sub LinkKeyList {
@@ -1365,15 +1382,6 @@ sub LinkKeyList {
 
 return a hash with all existing links of a given object
 
-Return
-    %LinkKeyList = (
-        5   => $DataOfItem5,
-        9   => $DataOfItem9,
-        12  => $DataOfItem12,
-        212 => $DataOfItem212,
-        332 => $DataOfItem332,
-    );
-
     my %LinkKeyList = $LinkObject->LinkKeyListWithData(
         Object1   => 'Ticket',
         Key1      => '321',
@@ -1384,6 +1392,17 @@ Return
         UserID    => 1,
     );
 
+
+Return:
+
+    %LinkKeyList = (
+        5   => $DataOfItem5,
+        9   => $DataOfItem9,
+        12  => $DataOfItem12,
+        212 => $DataOfItem212,
+        332 => $DataOfItem332,
+    );
+
 =cut
 
 sub LinkKeyListWithData {
@@ -1749,7 +1768,12 @@ sub TypeLookup {
 
 get a link type
 
-Return
+    %TypeData = $LinkObject->TypeGet(
+        TypeID => 444,
+    );
+
+Return:
+
     $TypeData{TypeID}
     $TypeData{Name}
     $TypeData{SourceName}
@@ -1760,9 +1784,7 @@ Return
     $TypeData{ChangeTime}
     $TypeData{ChangeBy}
 
-    %TypeData = $LinkObject->TypeGet(
-        TypeID => 444,
-    );
+
 
 =cut
 
@@ -1844,7 +1866,7 @@ sub TypeGet {
 
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message =>
+            Message  =>
                 "The $Argument '$Type{$Argument}' is invalid in SysConfig (LinkObject::Type)!",
         );
         return;
@@ -1868,7 +1890,10 @@ sub TypeGet {
 
 return a 2 dimensional hash list of all valid link types
 
-Return
+    my %TypeList = $LinkObject->TypeList();
+
+Return:
+
     $TypeList{
         Normal => {
             SourceName => 'Normal',
@@ -1880,8 +1905,6 @@ Return
         },
     }
 
-    my %TypeList = $LinkObject->TypeList();
-
 =cut
 
 sub TypeList {
@@ -1928,7 +1951,10 @@ sub TypeList {
 
 return a 2 dimensional hash list of all type groups
 
-Return
+    my %TypeGroupList = $LinkObject->TypeGroupList();
+
+Return:
+
     %TypeGroupList = (
         001 => [
             'Normal',
@@ -1944,8 +1970,6 @@ Return
         ],
     );
 
-    my %TypeGroupList = $LinkObject->TypeGroupList();
-
 =cut
 
 sub TypeGroupList {
@@ -1979,7 +2003,7 @@ sub TypeGroupList {
             # log the error
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message =>
+                Message  =>
                     "The Argument '$Type' is invalid in SysConfig (LinkObject::TypeGroup)!",
             );
 
@@ -2009,7 +2033,7 @@ sub TypeGroupList {
             # log the error
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message =>
+                Message  =>
                     "The LinkType '$Type' is invalid in SysConfig (LinkObject::TypeGroup)!",
             );
 
@@ -2194,16 +2218,17 @@ sub StateLookup {
 
 return a hash list of all valid link states
 
-Return
+    my %StateList = $LinkObject->StateList(
+        Valid => 0,   # (optional) default 1 (0|1)
+    );
+
+Return:
+
     $StateList{
         4 => 'Valid',
         8 => 'Temporary',
     }
 
-    my %StateList = $LinkObject->StateList(
-        Valid => 0,   # (optional) default 1 (0|1)
-    );
-
 =cut
 
 sub StateList {
@@ -2246,9 +2271,9 @@ sub StateList {
 checks read permission for a given object and UserID.
 
     $Permission = $LinkObject->ObjectPermission(
-        Object  => 'Ticket',
-        Key     => 123,
-        UserID  => 1,
+        Object => 'Ticket',
+        Key    => 123,
+        UserID => 1,
     );
 
 =cut
@@ -2282,18 +2307,19 @@ sub ObjectPermission {
 
 return a hash of object descriptions
 
-Return
+    %Description = $LinkObject->ObjectDescriptionGet(
+        Object => 'Ticket',
+        Key    => 123,
+        UserID => 1,
+    );
+
+Return:
+
     %Description = (
         Normal => '',
         Long   => '',
     );
 
-    %Description = $LinkObject->ObjectDescriptionGet(
-        Object  => 'Ticket',
-        Key     => 123,
-        UserID  => 1,
-    );
-
 =cut
 
 sub ObjectDescriptionGet {
@@ -2327,6 +2353,13 @@ sub ObjectDescriptionGet {
 
 return a hash reference of the search results.
 
+    $ObjectList = $LinkObject->ObjectSearch(
+        Object       => 'ITSMConfigItem',
+        SubObject    => 'Computer',        # (optional)
+        SearchParams => $HashRef,          # (optional)
+        UserID       => 1,
+    );
+
 Returns:
 
     $ObjectList = {
@@ -2341,13 +2374,6 @@ Returns:
         },
     };
 
-    $ObjectList = $LinkObject->ObjectSearch(
-        Object       => 'ITSMConfigItem',
-        SubObject    => 'Computer'         # (optional)
-        SearchParams => $HashRef,          # (optional)
-        UserID       => 1,
-    );
-
 =cut
 
 sub ObjectSearch {
@@ -2399,7 +2425,9 @@ sub _LinkListRaw {
         'Cache::LinkListRaw'
         . '::Direction' . $Param{Direction}
         . '::ObjectID' . $Param{ObjectID}
-        . '::StateID' . $Param{StateID};
+        . '::StateID' . $Param{StateID}
+        . '::Key' . $Param{Key};
+
     my $CachedLinks = $Kernel::OM->Get('Kernel::System::Cache')->Get(
         Type => $Self->{CacheType},
         Key  => $CacheKey,
@@ -2413,7 +2441,11 @@ sub _LinkListRaw {
 
         # prepare SQL statement
         my $TypeSQL = '';
-        my @Bind    = ( \$Param{ObjectID}, \$Param{StateID} );
+        my @Bind    = (
+            \$Param{ObjectID},
+            \$Param{Key},
+            \$Param{StateID},
+        );
 
         # get fields based on type
         my $SQL;
@@ -2421,13 +2453,15 @@ sub _LinkListRaw {
             $SQL =
                 'SELECT target_object_id, target_key, type_id, source_key'
                 . ' FROM link_relation'
-                . ' WHERE source_object_id = ?';
+                . ' WHERE source_object_id = ?'
+                . ' AND source_key = ?';
         }
         else {
             $SQL =
                 'SELECT source_object_id, source_key, type_id, target_key'
                 . ' FROM link_relation'
-                . ' WHERE target_object_id = ?';
+                . ' WHERE target_object_id = ?'
+                . ' AND target_key = ?';
         }
         $SQL .= ' AND state_id = ?' . $TypeSQL;
 
