@@ -89,7 +89,8 @@ Check if provided EffectiveValue matches structure defined in XMLContentParsed.
         },
     );
 
-Result:
+Returns:
+
     %Result = (
         EffectiveValue => {                     # Note for VacationDaysOneTime ValueTypes EffectiveValue is not changed.
             '2014' => {
@@ -297,7 +298,7 @@ Extracts the effective value from a XML parsed setting.
                     '1' => 'New Year\'s Day',
                 },
             },
-            ...
+            # ...
         },
         DefaultValue   => 'Product 5',      # (optional)
         Class          => 'My class',       # (optional)
