@@ -246,9 +246,9 @@ my @NeededModules = (
         Required  => 1,
         Comment   => 'Required to generate UUIDs.',
         InstTypes => {
-            aptget => undef,
+            aptget => 'libdata-uuid-perl',
             emerge => undef,
-            yum    => undef,
+            yum    => 'perl-Data-UUID',
             zypper => undef,
             ports  => undef,
         },
@@ -385,7 +385,7 @@ my @NeededModules = (
     {
         Module          => 'Hash::Merge',
         VersionRequired => '0.300',
-        Required        => 0,
+        Required        => 1,
         Comment         => 'Required for the creation of Excel statistical reports.',
         InstTypes       => {
             aptget => 'libhash-merge-perl',
@@ -400,7 +400,7 @@ my @NeededModules = (
         Comment   => 'Required for calendar events.',
         InstTypes => {
             aptget => 'libical-parser-perl',
-            emerge => 'perl-core/iCal-Parser',
+            emerge => 'dev-perl/iCal-Parser',
             zypper => 'perl-iCal-Parser',
             ports  => 'devel/p5-iCal-Parser',
         },
@@ -425,7 +425,7 @@ my @NeededModules = (
     {
         Module   => 'JavaScript::Minifier::XS',
         Required => 0,
-        Comment =>
+        Comment  =>
             'Alternative to JavaScript::Minifier in XS, which is slightly faster than JavaScript::Minifier (pure Perl).',
         InstTypes => {
             aptget => 'libjavascript-minifier-xs-perl',
@@ -437,7 +437,7 @@ my @NeededModules = (
     {
         Module   => 'Jq',
         Required => 0,
-        Comment =>
+        Comment  =>
             'Support for extended condition checking via Jq for the generic interface.',
         InstTypes => {
             aptget => undef,
@@ -460,7 +460,7 @@ my @NeededModules = (
     {
         Module   => 'List::Util::XS',
         Required => 1,
-        Comment =>
+        Comment  =>
             "Do a 'force install Scalar::Util' via cpan shell to fix this problem. Please make sure to have an c compiler and make installed before.",
         InstTypes => {
             aptget => 'libscalar-list-utils-perl',
