@@ -37,17 +37,25 @@ sub Run {
 
     my @Tasks = (
         {
-            Message => 'Increase size of columns of database table standard_template',
-            Module  => 'StandardTemplate',
-        },
-        {
-            Message => 'Create missing primary keys for database tables.',
-            Module  => 'CreatePrimaryKeys',
-        },
-        {
-            Message => 'Increase size of columns of database table search_profile',
+            Message => 'Increase size of columns of database table search_profile.',
             Module  => 'SearchProfile',
         },
+        {
+            Message => 'Create new communication channel Web.',
+            Module  => 'CreateCommunicationChannelWeb',
+        },
+        {
+            Message => 'Create database table translation.',
+            Module  => 'Translation',
+        },
+        {
+            Message => 'Create database table article_color.',
+            Module  => 'ArticleColor',
+        },
+        {
+            Message => 'Create table for user process preferences support.',
+            Module  => 'ProcessPreferences',
+        },
     );
 
     return 1   if !@Tasks;
